@@ -28,7 +28,7 @@ use Ref::Util qw(
 );
 use Carp 'croak';
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 our @EXPORT_OK = qw(
   _assert_import_list_is_valid
@@ -44,6 +44,10 @@ our @EXPORT_OK = qw(
 sub _enabled_features  {qw/signatures postderef postderef_qq :5.20/}             # internal use only
 sub _disabled_warnings {qw/experimental::signatures experimental::postderef/}    # internal use only
 
+warnings::register_categories(
+    'MooseX::Extended::naked_fields',
+);
+
 # Should this be in the metaclass? It feels like it should, but
 # the MOP really doesn't support these edge cases.
 my %CONFIG_FOR;
@@ -234,8 +238,9 @@ sub _apply_optional_features ( $config, $for_class ) {
 }
 
 sub param ( $meta, $name, %opt_for ) {
-    $opt_for{is}       //= 'ro';
-    $opt_for{required} //= 1;
+    $opt_for{is}          //= 'ro';
+    $opt_for{required}    //= 1;
+    $opt_for{_call_level} //= 1;
 
     # "has [@attributes]" versus "has $attribute"
     foreach my $attr ( is_plain_arrayref($name) ? @$name : $name ) {
@@ -249,7 +254,8 @@ sub param ( $meta, $name, %opt_for ) {
 }
 
 sub field ( $meta, $name, %opt_for ) {
-    $opt_for{is} //= 'ro';
+    $opt_for{is}          //= 'ro';
+    $opt_for{_call_level} //= 1;
 
     # "has [@attributes]" versus "has $attribute"
     foreach my $attr ( is_plain_arrayref($name) ? @$name : $name ) {
@@ -318,12 +324,32 @@ sub _add_attribute ( $attr_type, $meta, $name, %opt_for ) {
         }
     }
 
+    if ( 'rwp' eq $opt_for{is} ) {
+        $opt_for{writer} = "_set_$name";
+    }
+
     if ( exists $opt_for{writer} && defined $opt_for{writer} ) {
         $opt_for{is} = 'rw';
     }
 
     %opt_for = _maybe_add_cloning_method( $meta, $name, %opt_for );
 
+    if (    not exists $opt_for{accessor}
+        and not exists $opt_for{writer}
+        and not exists $opt_for{default}
+        and not exists $opt_for{builder}
+        and not defined $opt_for{init_arg}
+        and $opt_for{is} eq 'ro' )
+    {
+
+        my $call_level = 1 + $opt_for{_call_level};
+        my ( $package, $filename, $line ) = caller($call_level);
+        Carp::carp("$attr_type '$name' is read-only and has no init_arg or default, defined at $filename line $line\n")
+          if $] ge '5.028'
+          and warnings::enabled_at_level( 'MooseX::Extended::naked_fields', $call_level );
+    }
+
+    delete $opt_for{_call_level};
     _debug( "Setting $attr_type, '$name'", \%opt_for );
     $meta->add_attribute( $name, %opt_for );
 }
@@ -455,7 +481,7 @@ MooseX::Extended::Core - Internal module for MooseX::Extended
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 DESCRIPTION
 
